@@ -23,19 +23,37 @@ module GitalyServer
     def fetch_remote(request, call)
       gitlab_projects = Gitlab::Git::GitlabProjects.from_gitaly(request.repository, call)
 
+      remote_name = request.remote
+
+      repository = nil
+
+      if request.remote_params
+        params = request.remote_params
+        repository = Gitlab::Git::Repository.from_gitaly(request.repository, call)
+
+        mirror_refmaps = parse_refmaps(params.mirror_refmaps)
+
+        repository.add_remote(params.name, params.url, mirror_refmap: mirror_refmaps)
+        remote_name = params.name
+      end
+
       success = Gitlab::Git::SshAuth.from_gitaly(request).setup do |env|
-        gitlab_projects.fetch_remote(
-          request.remote,
-          request.timeout,
-          force: request.force,
-          tags: !request.no_tags,
-          env: env
-        )
+        Gitlab::Git::HttpAuth.from_gitaly(request, call) do
+          gitlab_projects.fetch_remote(
+            remote_name,
+            request.timeout,
+            force: request.force,
+            tags: !request.no_tags,
+            env: env
+          )
+        end
       end
 
       raise GRPC::Unknown.new("Fetching remote #{request.remote} failed: #{gitlab_projects.output}") unless success
 
       Gitaly::FetchRemoteResponse.new
+    ensure
+      repository&.remove_remote(remote_name)
     end
 
     def write_config(request, call)
@@ -84,11 +102,11 @@ module GitalyServer
     private
 
     OPERATION_MAP = {
-      added:        Gitaly::GetRawChangesResponse::RawChange::Operation::ADDED,
-      copied:       Gitaly::GetRawChangesResponse::RawChange::Operation::COPIED,
-      deleted:      Gitaly::GetRawChangesResponse::RawChange::Operation::DELETED,
-      modified:     Gitaly::GetRawChangesResponse::RawChange::Operation::MODIFIED,
-      renamed:      Gitaly::GetRawChangesResponse::RawChange::Operation::RENAMED,
+      added: Gitaly::GetRawChangesResponse::RawChange::Operation::ADDED,
+      copied: Gitaly::GetRawChangesResponse::RawChange::Operation::COPIED,
+      deleted: Gitaly::GetRawChangesResponse::RawChange::Operation::DELETED,
+      modified: Gitaly::GetRawChangesResponse::RawChange::Operation::MODIFIED,
+      renamed: Gitaly::GetRawChangesResponse::RawChange::Operation::RENAMED,
       type_changed: Gitaly::GetRawChangesResponse::RawChange::Operation::TYPE_CHANGED
     }.freeze
 
