@@ -406,6 +406,8 @@ module Gitlab
 
           rebase_sha = run_git!(%w[rev-parse HEAD], chdir: rebase_path, env: env).strip
 
+          yield rebase_sha if block_given?
+
           update_branch(branch, user: user, newrev: rebase_sha, oldrev: branch_sha)
 
           rebase_sha
@@ -426,7 +428,7 @@ module Gitlab
         with_worktree(squash_path, branch, sparse_checkout_files: diff_files, env: env) do
           # Apply diff of the `diff_range` to the worktree
           diff = run_git!(%W[diff --binary #{diff_range}])
-          run_git!(%w[apply --index --whitespace=nowarn], chdir: squash_path, env: env, include_stderr: true) do |stdin|
+          run_git!(%w[apply --index --3way --whitespace=nowarn], chdir: squash_path, env: env, include_stderr: true) do |stdin|
             stdin.binmode
             stdin.write(diff)
           end
@@ -488,12 +490,9 @@ module Gitlab
       end
 
       # rubocop:disable Metrics/ParameterLists
-      def multi_action(
-        user, branch_name:, message:, actions:,
-        author_email: nil, author_name: nil,
-        start_branch_name: nil, start_repository: self, force: false
-      )
-
+      def multi_action(user, branch_name:, message:, actions:,
+                       author_email: nil, author_name: nil,
+                       start_branch_name: nil, start_repository: self, force: false)
         OperationService.new(user, self).with_branch(
           branch_name,
           start_branch_name: start_branch_name,
