@@ -200,42 +200,6 @@ describe Gitlab::Git::Repository do # rubocop:disable Metrics/BlockLength
     end
   end
 
-  describe '#raw_changes_between' do
-    let(:changes) { repository.raw_changes_between(old_rev, new_rev) }
-
-    context 'initial commit' do
-      let(:old_rev) { Gitlab::Git::BLANK_SHA }
-      let(:new_rev) { '1a0b36b3cdad1d2ee32457c102a8c0b7056fa863' }
-
-      it 'returns the changes' do
-        expect(changes).to be_present
-        expect(changes.size).to eq(3)
-      end
-    end
-
-    context 'with an invalid rev' do
-      let(:old_rev) { 'foo' }
-      let(:new_rev) { 'bar' }
-
-      it 'returns an error' do
-        expect { changes }.to raise_error(Gitlab::Git::Repository::GitError)
-      end
-    end
-
-    context 'with valid revs' do
-      let(:old_rev) { 'fa1b1e6c004a68b7d8763b86455da9e6b23e36d6' }
-      let(:new_rev) { '4b4918a572fa86f9771e5ba40fbd48e1eb03e2c6' }
-
-      it 'returns the changes' do
-        expect(changes.size).to eq(9)
-        expect(changes.first.operation).to eq(:modified)
-        expect(changes.first.new_path).to eq('.gitmodules')
-        expect(changes.last.operation).to eq(:added)
-        expect(changes.last.new_path).to eq('files/lfs/picture-invalid.png')
-      end
-    end
-  end
-
   describe '#merge_base' do
     where(:from, :to, :result) do
       '570e7b2abdd848b95f2f578043fc23bd6f6fd24d' | '40f4a7a617393735a95a0bb67b08385bc1e7c66d' | '570e7b2abdd848b95f2f578043fc23bd6f6fd24d'
@@ -764,42 +728,6 @@ describe Gitlab::Git::Repository do # rubocop:disable Metrics/BlockLength
     end
   end
 
-  describe '#parse_raw_diff_line' do
-    let(:diff_data) { repository.parse_raw_diff_line(diff_line) }
-
-    context 'valid diff line' do
-      let(:diff_line) { ":100644 100644 454bade 2b75299 M\tmodified-file.txt" }
-
-      it 'returns the diff data' do
-        expect(diff_data).to eq(["100644", "100644", "2b75299", "M\tmodified-file.txt"])
-      end
-
-      context 'added file' do
-        let(:diff_line) { ":000000 100644 0000000 5579569 A\tnew-file.txt" }
-
-        it 'returns the new blob id' do
-          expect(diff_data[2]).to eq('5579569')
-        end
-      end
-
-      context 'deleted file' do
-        let(:diff_line) { ":100644 000000 26b5bd5 0000000 D\tremoved-file.txt" }
-
-        it 'returns the old blob id' do
-          expect(diff_data[2]).to eq('26b5bd5')
-        end
-      end
-    end
-
-    context 'invalid diff line' do
-      let(:diff_line) { '' }
-
-      it 'raises an ArgumentError' do
-        expect { diff_data }.to raise_error(ArgumentError)
-      end
-    end
-  end
-
   describe "#commit_patches" do
     let(:repository) { gitlab_git_from_gitaly(new_mutable_test_repo) }
     let(:testdata_dir) { File.join(File.dirname(__FILE__), '../../../../../internal/service/operations/testdata') }
